@@ -1,18 +1,30 @@
+from typing import Callable
+
 from packaging import version as _v
 
 from npr import __version__
 
 
+class MigrationException(Exception):
+    def __init__(self, message):
+        self.message = message
+
+
 class Migrator:
-    versions = {}
+    versions: dict[str, Callable[[dict], dict]] = {}
 
     def register(self, version: str):
         def __decorator__(f):
             if version in self.versions:
-                raise Exception()
+                raise MigrationException(
+                    f"Migration v{version} is overwriting an existing migration."
+                )
 
             if _v.parse(version) > _v.parse(__version__):
-                raise Exception()
+                raise MigrationException(
+                    f"Unable to register migration v{version}. "
+                    f"Registered version is greater than app version v{__version__}"
+                )
 
             self.versions[version] = f
 
