@@ -9,8 +9,11 @@ def migration(obj: dict):
 
     faves = []
     for f in favorites:
-        f["name"] = f.pop("title")
+        f["name"] = f.get("title")
+        del f["title"]
+        faves.append(f)
 
-    last_played["name"] = last_played.pop("title")
+    last_played["name"] = last_played.get("title")
+    del last_played["title"]
 
     return {"__version__": __version__, "favorites": faves, "last_played": last_played}
