@@ -15,6 +15,7 @@ class AppState:
     favorites: list[Stream]
     last_played: Stream | None
 
+    __version__: str = __version__
     player: Player = Player(vlc.MediaPlayer)
 
     @classmethod
@@ -24,15 +25,19 @@ class AppState:
         with state_file.open() as f:
             try:
                 c = migrator.migrate(json.load(f))
-                return cls(
-                    favorites=[Stream(**s) for s in c["favorites"]],
-                    last_played=Stream(**c["last_played"])
-                    if c["last_played"]
-                    else None,
-                )
+                return cls._load_dict(c)
             except json.JSONDecodeError:
                 return cls([], None)
 
+    @classmethod
+    def _load_dict(cls, state: dict):
+        return cls(
+            favorites=[Stream(**s) for s in state["favorites"]],
+            last_played=Stream(**state["last_played"])
+            if state["last_played"]
+            else None,
+        )
+
     def write(self, state_file: Path = NPRRC):
         with state_file.open("w") as f:
             _serialized = {
